@@ -66,7 +66,7 @@ def test_create_empty_draft(app, service, identity_simple):
     assert draft['conceptid']
     assert draft._record.pid.status == PIDStatus.NEW
     assert draft._record.conceptpid.status == PIDStatus.NEW
-    assert draft_dict['errors']['metadata']['title']
+    assert draft_dict['errors'][0]['field'] == 'metadata.title'
 
 
 def test_read_draft(app, service, identity_simple, input_data):
@@ -111,7 +111,7 @@ def test_update_draft_invalid_field(app, service, identity_simple, input_data):
 
     assert draft.id == updated_draft.id
     assert updated_draft["metadata"]['title'] == orig_title
-    assert updated_draft_dict["errors"]["metadata"]['title']
+    assert updated_draft_dict['errors'][0]['field'] == 'metadata.title'
 
 
 def test_delete_draft(app, service, identity_simple, input_data):
